flutter_easy_permission_manager library

Classes

EasyPermissions
Permission
Defines the permissions which can be checked and requested.
PermissionAnalytics
Detailed permission analytics
PermissionConfig
PermissionGroup
Represents a group of related permissions
PermissionHelper
PermissionRequest
Represents a permission request with its configuration
PermissionResult
PermissionStatusInfo
Represents the status of a permission with additional metadata
PermissionWithService
A special kind of permission, used to access a service.
PlatformPermissionInfo
Platform-specific permission information

Enums

PermissionStatus
Defines the state of a Permission.
ServiceStatus
Defines the different states a service can be in.

Extensions

FuturePermissionStatusGetters on Future<PermissionStatus>
Utility getter extensions for the Future<PermissionStatus> type.
FutureServiceStatusGetters on Future<ServiceStatus>
Utility getter extensions for the Future<ServiceStatus> type.
PermissionActions on Permission
Actions that can be executed on a permission.
PermissionCheckShortcuts on Permission
Shortcuts for checking the status of a Permission.
PermissionListActions on List<Permission>
Actions that can be taken on a List of Permissions.
PermissionStatusGetters on PermissionStatus
Utility getter extensions for the PermissionStatus type.
ServicePermissionActions on PermissionWithService
Actions that apply only to permissions that have an associated service.
ServiceStatusGetters on ServiceStatus
Utility getter extensions for the ServiceStatus type.

Functions

openAppSettings() Future<bool>
Opens the app settings page.